@@ -1905,7 +1905,8 @@ gnome_rr_output_is_laptop (GnomeRROutput *output)
 	&& (strstr (output->name, "lvds") ||  /* Most drivers use an "LVDS" prefix... */
 	    strstr (output->name, "LVDS") ||
 	    strstr (output->name, "Lvds") ||
-	    strstr (output->name, "LCD")))    /* ... but fglrx uses "LCD" in some versions.  Shoot me now, kthxbye. */
+	    strstr (output->name, "LCD")  ||  /* ... but fglrx uses "LCD" in some versions.  Shoot me now, kthxbye. */
+	    strstr (output->name, "eDP")))    /* eDP is for internal laptop panel connections */
 	return TRUE;
 
     return FALSE;
